package logic

import (
	"errors"
	"fusenapi/model/gmodel"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"
	"strconv"

	"context"

	"fusenapi/server/ldap-admin/internal/svc"
	"fusenapi/server/ldap-admin/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
	"gorm.io/gorm"
)

type SetLdapCasbinRuleLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewSetLdapCasbinRuleLogic(ctx context.Context, svcCtx *svc.ServiceContext) *SetLdapCasbinRuleLogic {
	return &SetLdapCasbinRuleLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *SetLdapCasbinRuleLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *SetLdapCasbinRuleLogic) SetLdapCasbinRule(req *types.SetLdapCasbinRuleReq, userinfo *auth.UserInfo) (resp *basic.Response) {
	// 返回值必须调用Set重新返回, resp可以空指针调用 resp.SetStatus(basic.CodeOK, data)
	// userinfo 传入值时, 一定不为null
	resLdapGroupInfo, err := l.svcCtx.AllModels.LdapGroup.FindOneById(l.ctx, req.GroupId)
	if err != nil {
		if errors.Is(err, gorm.ErrRecordNotFound) {
			basic.CodeServiceErr.Message = "权限组记录不存在"
		} else {
			basic.CodeServiceErr.Message = "系统出错"
		}
		return resp.SetStatus(basic.CodeServiceErr)
	}
	resLdapApiList, err := l.svcCtx.AllModels.LdapApis.FindAll(l.ctx, l.svcCtx.MysqlConn.Where("id IN ?", req.ApIds))
	if err != nil {
		return resp.SetStatus(basic.CodeServiceErr)
	}
	if len(resLdapApiList) > 0 {
		var groupIdStr = strconv.Itoa(int(resLdapGroupInfo.Id))
		var ldapCasbinRules []gmodel.LdapCasbinRule
		for _, ldapApi := range resLdapApiList {
			var apiIdStr = strconv.Itoa(int(ldapApi.Id))
			ldapCasbinRules = append(ldapCasbinRules, gmodel.LdapCasbinRule{
				V0: &groupIdStr,
				V1: ldapApi.Path,
				V2: ldapApi.Method,
				V3: &apiIdStr,
			})
		}
		resCreateInBatches := l.svcCtx.MysqlConn.WithContext(l.ctx).CreateInBatches(ldapCasbinRules, 100)
		if resCreateInBatches.Error != nil {
			basic.CodeServiceErr.Message = "系统出错"
			return resp.SetStatus(basic.CodeServiceErr)
		}
	}

	return resp.SetStatus(basic.CodeOK)
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *SetLdapCasbinRuleLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
